==> e2e-cypress-dsl-9.0.4.zip: dsl/pages/folder-templates-list-page.js <==
import AddTemplateDropdown from './add-template-dropdown';

export default class FolderTemplatesListPage {

    constructor() {
        cy.get('#templates').should('be.visible');
    }

    addTemplate() {
        return new AddTemplateDropdown('#list-add-template');
    }

    expectTemplatesCountToBe(count) {
        cy.get(".raised-link").should('have.length', count);
        return this;
    }

    createNewTemplate() {
        element(By.css(".new-template")).click();
        return new TemplatePropertiesPage();
    }

    openTemplateByName(templateName) {
        Browser.waitFor('.template');
        element(By.$(`.template:contains('${templateName}') .raised-link`)).click();
        return new ReleasePage();
    }

    openImportTemplateDialog() {
        element(By.css(".import-template")).click();
        return new ImportTemplateDialog();
    }

    searchBy(criteria) {
        cy.get(".searchFilter").clear();
        cy.get(".searchFilter").type(criteria);
        cy.wait(500);
        return this;
    }

    copy(originTitle, targetTitle, optionalArguments) {
        const {expectFailure} = optionalArguments || {};

        element(By.$(`.template:contains('${originTitle}') .copy`)).click();

        const title = element(By.model('ctrl.copyOfTemplate.title'));
        title.clear();
        title.sendKeys(targetTitle);

        const description = element(By.model('ctrl.copyOfTemplate.description'));
        description.clear();
        description.sendKeys('description');

        element(By.$('.modal:visible .continue')).click();
        if (expectFailure) {
            expect(browser.isElementPresent(By.$(`.form-errors li:contains(\"${expectFailure}\"):visible`))).toBe(true);
            element(By.$('.modal:visible .close')).click();
        } else {
            new TemplatePage();
            Page.openTemplatesList();
        }

        return this;
    }

    expectTemplateVisible(title, expected = true) {
        cy.get(`.template:contains('${title}')`).should('have.length', expected ? 1 : 0);
        return this;
    }

    createNewTemplate() {
        element(By.css(".new-template")).click();
        return new TemplatePropertiesPage();
    }

    delete(title) {
        cy.get(`.template:contains('${title}') .delete`).click();
        cy.get('.modal .continue').click();
        return this;
    }

    openMoveDialog(title) {
        Browser.waitFor(`.template:contains(${title})`);
        element(By.$(`.template:contains('${title}') .move`)).click();
        return new MoveDialog();
    }
}


class MoveDialog {
    constructor() {
        Browser.waitFor('folder-explorer');
    }

    selectFolder(folder) {
        element(By.$(`.ui-grid-row-title:contains('${folder}')`)).click();
        return this;
    }

    submitMove() {
        element(By.$('.modal .continue')).click();
        return this;
    }

    expand(folder) {
        const toggleIcon = element(By.$(`.ui-grid-row:contains('${folder}') .toggle-icon`));
        browser.executeScript('arguments[0].click();', toggleIcon.getWebElement());
        return this;
    }

    expectFolderDisabled(disabledFolder) {
        expect(element(By.$(`.modal-body span.can-click-disabled:contains('${disabledFolder}')`))).toBePresent(true);
        return this;
    }

    expectMoveButtonDisabled(enabled) {
        expect(element(By.$("[disabled]"))).toBePresent(enabled);
        return this;
    }

    expectMergeActionEnabled(enabled) {
        expect(element(By.$(`.merge-action input${enabled ? '' : '[disabled]'}`))).toBePresent(true);
        return this;
    }

    expectMovePermissionDialog(folder) {
        expect(element(By.$(`.move-template-permissions:contains(folder takes its permissions from ${folder})`))).toBePresent(true);
        return this;
    }

    chooseOption(name) {
        element(By.$(`.${name.toLowerCase()}-action input`)).click();
        return this;
    }
}

==> e2e-cypress-dsl-10.2.1.zip: dsl/pages/folder-templates-list-page.js <==
import AddTemplateDropdown from './add-template-dropdown';
import ReleasePage from "./release-page";
import TemplateMoveDialog from '../components/template-move-dialog';

export default class FolderTemplatesListPage {

    constructor() {
        cy.get('#templates').should('be.visible');
    }

    getMoveButtonElement(title) {
        return cy.get(`.template:contains('${title}') .move`);
    }

    addTemplate() {
        return new AddTemplateDropdown('#list-add-template');
    }

    createNewTemplate() {
        cy.get(".new-template").click();
        return new TemplatePropertiesPage();
    }

    openTemplateByName(templateName) {
        cy.get(`.template:contains('${templateName}') .raised-link`).click();
        return new ReleasePage();
    }

    openImportTemplateDialog() {
        element(By.css(".import-template")).click();
        return new ImportTemplateDialog();
    }

    searchBy(criteria) {
        cy.get(".searchFilter").clear();
        cy.get(".searchFilter").type(criteria);
        cy.wait(500);
        return this;
    }

    delete(title) {
        cy.get(`.template:contains('${title}') .delete`).click();
        cy.get('.modal .continue').click();
        return this;
    }

    clickOnMoveButton(title) {
        this.getMoveButtonElement(title).click();
        return new TemplateMoveDialog();
    }

    expectTemplatesCountToBe(count) {
        cy.get(".raised-link").should('have.length', count);
        return this;
    }

    expectTemplateVisible(title, expected = true) {
        cy.get(`.template:contains('${title}')`).should('have.length', expected ? 1 : 0);
        return this;
    }
}
